#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 html-conduit
version:              1.3.2.2
visibility:           public
id:                   html-conduit-1.3.2.2-4tOevn1aOgYBPXkOKPc2q6
key:                  html-conduit-1.3.2.2-4tOevn1aOgYBPXkOKPc2q6
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/xml
synopsis:             Parse HTML documents using xml-conduit datatypes.
description:
    This package uses tagstream-conduit for its parser. It automatically balances mismatched tags, so that there shouldn'\''t be any parse failures. It does not handle a full HTML document rendering, such as adding missing html and head tags. Note that, since version 1.3.1, it uses an inlined copy of tagstream-conduit with entity decoding bugfixes applied.

category:             Web, Text, Conduit
abi:                  8fb59a3c1a90cf65549a76485ac97a76
exposed:              True
exposed-modules:      Text.HTML.DOM
hidden-modules:       Text.HTML.TagStream
import-dirs:          /usr/lib/ghc-9.6.6/site-local/html-conduit-1.3.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/html-conduit-1.3.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/html-conduit-1.3.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-html-conduit
hs-libraries:         HShtml-conduit-1.3.2.2-4tOevn1aOgYBPXkOKPc2q6
depends:
    attoparsec-0.14.4-L7yQnQokRKL4IK7J2HszTx base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-7ztpQFzxkQu9fYslJzAtaH
    conduit-extra-1.3.8-EtHHdCy2JFLEIdUwh75e4q containers-0.6.7
    resourcet-1.2.6-K6JBNnVEw7T4VmkwByHPd3 text-2.0.2
    transformers-0.6.1.0 xml-conduit-1.9.1.4-L84WKBwLATzGXqlKjBDiNr
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau

haddock-interfaces:
    /usr/share/doc/haskell-html-conduit/html/html-conduit.haddock

haddock-html:         /usr/share/doc/haskell-html-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

